@@ -1,3 +1,6 @@
+from os.path import join
+from os.path import sep
+from pathlib import Path
 from pdf_play import __settings__ as settings
 from pdf_play.core import watermark
 from pdf_play.helpers import parse_user_args
@@ -13,7 +16,12 @@ def _watermark_mto(texts=('PDFPlay',), target_file=None, output_directory=None,
 def _watermark_otm(text='PDFPlay', target_files=None, output_directory=None,
                    font_name='Helvetica-Bold',
                    font_size='medium', text_alignment='diagonal'):
-    raise NotImplementedError('To be implemented...')
+    for target_file in target_files:
+        name_and_extension = target_file.split(sep)[-1]
+        name, extension = name_and_extension.split('.')
+        output_file = join(output_directory, f'{name}_watermarked.{extension}')
+        watermark(text, target_file, output_file, font_name=font_name,
+                  font_size=font_size, text_alignment=text_alignment)
 
 
 def _watermark_oto(text='PDFPlay', target_file=None, output_file=None,
@@ -29,7 +37,7 @@ def _watermark(args=None):
     type_ = args.type
     del args.type
     del args.command
-    type_map = dict(oto=_watermark_oto)
+    type_map = dict(oto=_watermark_oto, otm=_watermark_otm)
     type_map[type_](**vars(args))
 
 
